/*
    ES Knot
    Copyright 2005, 2006 Martin Storsj

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

    Martin Storsj
    martin@martin.st
*/

#include <avkon.hrh>
#include <aknnotewrappers.h>
#include <stringloader.h>
#include <flogger.h>
#include <knot.rsg>

#include "knot.pan"
#include "knotappui.h"
#include "knotappview.h"
#include "knot.hrh"
#include "knot.h"

void CKnotAppUi::ConstructL() {
	BaseConstructL();
	iAppView = CKnotAppView::NewL(ClientRect(), ETrue);
	AddToStackL(iAppView);
}

CKnotAppUi::CKnotAppUi() {
}

CKnotAppUi::~CKnotAppUi() {
	if (iAppView) {
		RemoveFromStack(iAppView);
		delete iAppView;
		iAppView = NULL;
	}
}

void CKnotAppUi::HandleCommandL(TInt aCommand) {
	switch(aCommand) {
	case EEikCmdExit:
	case EAknSoftkeyExit:
	case EAknSoftkeyBack:
		Exit();
		break;

	case EKnotUntextured:
		iAppView->iKnot->setTexMode(Knot::UNTEXTURED);
		break;

	case EKnotPlainTexture:
		iAppView->iKnot->setTexMode(Knot::PLAINTEX);
		break;

	case EKnotTexSpecular:
		iAppView->iKnot->setTexMode(Knot::TEXSPEC);
		break;

	case EKnotCelshaded:
		iAppView->iKnot->setTexMode(Knot::CELSHADED);
		break;

	case EKnotDrawEGLWindow:
		iAppView->SetDrawMode(CKnotAppView::EEGLWindow);
		break;

	case EKnotDrawDouble:
		iAppView->SetDrawMode(CKnotAppView::EDoubleBuf);
		break;

	case EKnotDrawDSA:
		iAppView->SetDrawMode(CKnotAppView::EDSA);
		break;

	case EKnotWinFullscreen:
	case EKnotWinWindowed:
		iAppView->SetWindowMode(aCommand == EKnotWinFullscreen ? CKnotAppView::EFullscreen : CKnotAppView::EWindowed);
		break;

	case EKnotVertexUpdateOn:
	case EKnotVertexUpdateOff:
		iAppView->iKnot->setUpdateVertices(aCommand == EKnotVertexUpdateOn);
		break;

	case EKnotMotionBlurOn:
	case EKnotMotionBlurOff:
		iAppView->iKnot->setMotionBlur(aCommand == EKnotMotionBlurOn);
		break;

	case EKnotRadialBlurGlowOn:
	case EKnotRadialBlurOn:
	case EKnotRadialBlurOff:
		iAppView->iKnot->setRadialBlur(aCommand == EKnotRadialBlurOn || aCommand == EKnotRadialBlurGlowOn);
		iAppView->iKnot->setRadialGlow(aCommand == EKnotRadialBlurGlowOn);
		break;

	case EKnotMorph:
		iAppView->iKnot->startMorph();
		break;

	default:
		Panic(EKnotUi);
		break;
	}
}

void CKnotAppUi::HandleForegroundEventL(TBool aForeground) {
	iAppView->SetForeground(aForeground);
}

void CKnotAppUi::SetEmphasis(CCoeControl* aMenuControl, TBool aEmphasis) {
	iAppView->SetForeground(!aEmphasis);
}

void CKnotAppUi::DynInitMenuBarL(TInt aResourceId, CEikMenuBar* aMenuBar) {
	iAppView->SetForeground(EFalse);
}




